aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/widgets/InfoBoardWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ui/widgets/InfoBoardWidget.h')
-rw-r--r--src/ui/widgets/InfoBoardWidget.h91
1 files changed, 68 insertions, 23 deletions
diff --git a/src/ui/widgets/InfoBoardWidget.h b/src/ui/widgets/InfoBoardWidget.h
index 816da849..7f456777 100644
--- a/src/ui/widgets/InfoBoardWidget.h
+++ b/src/ui/widgets/InfoBoardWidget.h
@@ -1,4 +1,6 @@
/**
+ * Copyright (C) 2021 Saturneric
+ *
* This file is part of GpgFrontend.
*
* GpgFrontend is free software: you can redistribute it and/or modify
@@ -6,19 +8,21 @@
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Foobar is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with Foobar. If not, see <https://www.gnu.org/licenses/>.
+ * along with GpgFrontend. If not, see <https://www.gnu.org/licenses/>.
+ *
+ * The initial version of the source code is inherited from
+ * the gpg4usb project, which is under GPL-3.0-or-later.
*
- * The initial version of the source code is inherited from gpg4usb-team.
- * Their source code version also complies with GNU General Public License.
+ * All the source code of GpgFrontend was modified and released by
+ * Saturneric<[email protected]> starting on May 12, 2021.
*
- * The source code version of this software was modified and released
- * by Saturneric<[email protected]> starting on May 12, 2021.
+ * SPDX-License-Identifier: GPL-3.0-or-later
*
*/
@@ -26,7 +30,7 @@
#define __VERIFYNOTIFICATION_H__
#include "PlainTextEditorPage.h"
-#include "gpg/result_analyse/VerifyResultAnalyse.h"
+#include "core/function/result_analyse/GpgVerifyResultAnalyse.h"
#include "ui/details/VerifyDetailsDialog.h"
class Ui_InfoBoard;
@@ -34,7 +38,7 @@ class Ui_InfoBoard;
namespace GpgFrontend::UI {
/**
- * @details Enumeration for the status of Verifylabel
+ * @details Enumeration for the status of Verify label
*/
typedef enum {
INFO_ERROR_OK = 0,
@@ -44,7 +48,7 @@ typedef enum {
} InfoBoardStatus;
/**
- * @brief Class for handling the verifylabel shown at buttom of a textedit-page
+ * @brief Class for handling the verify label shown at bottom of a textedit-page
*/
class InfoBoardWidget : public QWidget {
Q_OBJECT
@@ -57,45 +61,86 @@ class InfoBoardWidget : public QWidget {
*/
explicit InfoBoardWidget(QWidget* parent);
- void associateTextEdit(QTextEdit* edit);
+ /**
+ * @brief
+ *
+ * @param edit
+ */
+ void AssociateTextEdit(QTextEdit* edit);
- void associateTabWidget(QTabWidget* tab);
+ /**
+ * @brief
+ *
+ * @param tab
+ */
+ void AssociateTabWidget(QTabWidget* tab);
- void addOptionalAction(const QString& name,
+ /**
+ * @brief
+ *
+ * @param name
+ * @param action
+ */
+ void AddOptionalAction(const QString& name,
const std::function<void()>& action);
- void resetOptionActionsMenu();
+ /**
+ * @brief
+ *
+ */
+ void ResetOptionActionsMenu();
/**
* @details Set the text and background-color of verify notification.
*
* @param text The text to be set.
* @param verifyLabelStatus The status of label to set the specified color.
*/
- void setInfoBoard(const QString& text, InfoBoardStatus verifyLabelStatus);
+ void SetInfoBoard(const QString& text,
+ GpgFrontend::UI::InfoBoardStatus verify_label_status);
public slots:
- void slotReset();
+ /**
+ * @brief
+ *
+ */
+ void SlotReset();
/**
* @details Refresh the contents of dialog.
*/
- void slotRefresh(const QString& text, InfoBoardStatus status);
+ void SlotRefresh(const QString& text,
+ GpgFrontend::UI::InfoBoardStatus status);
private slots:
- void slotCopy();
+ /**
+ * @brief
+ *
+ */
+ void slot_copy();
- void slotSave();
+ /**
+ * @brief
+ *
+ */
+ void slot_save();
private:
- std::shared_ptr<Ui_InfoBoard> ui;
+ std::shared_ptr<Ui_InfoBoard> ui_; ///<
- QTextEdit* mTextPage{nullptr}; /** TextEdit associated to the notification */
- QTabWidget* mTabWidget{nullptr};
+ QTextEdit* m_text_page_{
+ nullptr}; ///< TextEdit associated to the notification
+ QTabWidget* m_tab_widget_{nullptr}; ///<
- void deleteWidgetsInLayout(QLayout* layout, int start_index = 0);
+ /**
+ * @brief
+ *
+ * @param layout
+ * @param start_index
+ */
+ void delete_widgets_in_layout(QLayout* layout, int start_index = 0);
};
} // namespace GpgFrontend::UI
@@ -6,19 +8,21 @@
* (at your option) any later version.
*
- * Foobar is distributed in the hope that it will be useful,
+ * GpgFrontend is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -57,45 +61,86 @@ class InfoBoardWidget : public QWidget {
*
* @param text The text to be set.
- * @param verifyLabelStatus The status of label to set the specified color.
+ * @param verify_label_status The status of label to set the specified color.
*/